@@ -4,7 +4,8 @@
     IC.UpdateInKer = NULL,
     all.verbose = FALSE,
     withICList = FALSE,
-    withPICList = FALSE
+    withPICList = FALSE,
+    modifyICwarn = TRUE
 )
 
 RobAStBaseOptions <- function(...) {
